@@ -8,9 +8,7 @@ from uuid import uuid4
 import json
 import requests
 from requests.exceptions import ConnectionError, HTTPError
-import logging
 from inspect import getmembers, isfunction, isclass, signature
-import sys
 from pythonjsonlogger import jsonlogger
 import datetime
 import logging
@@ -95,8 +93,7 @@ def remove_file(file_path):
 
 @huey.task()
 def do_transformations(uuid: uuid4, job_archive_path: str):
-    with tempfile.TemporaryDirectory() as tmp_dir:
-
+    with tempfile.TemporaryDirectory(dir=CONFIG["CIRCE_TEMP_DIR"]) as tmp_dir:
         handler: logging.FileHandler = logging.FileHandler("{}/out.log".format(tmp_dir))
         handler.setFormatter(
             CustomJsonFormatter("%(timestamp)s %(level)s %(name)s %(message)s")
@@ -137,7 +134,9 @@ def do_transformations(uuid: uuid4, job_archive_path: str):
                                 "time": _stamp(),
                             }
                         )
-                _, temp_zip_path = tempfile.mkstemp(suffix=".tar.gz")
+                _, temp_zip_path = tempfile.mkstemp(
+                    suffix=".tar.gz", dir=CONFIG["CIRCE_TEMP_DIR"]
+                )
                 with tarfile.open(temp_zip_path, "w:gz") as destination_archive:
                     destination_archive.add(tmp_dir, recursive=True, arcname="")
                 final_archive_path = "{}/done/{}.tar.gz".format(
